@@ -1,7 +1,7 @@
 /* GStreamer
- * Copyright 2010 ST-Ericsson SA 
+ * Copyright 2010 ST-Ericsson SA
  *  @author: Benjamin Gaignard <benjamin.gaignard@stericsson.com>
- *  
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,17 +24,19 @@
 
 #include "gstautoconvert.h"
 #include "gstautovideoconvert.h"
+#include "gstautovideoflip.h"
+#include "gstautodeinterlace.h"
 
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  gboolean ret;
+  gboolean ret = FALSE;
 
-  ret = gst_element_register (plugin, "autoconvert",
-      GST_RANK_NONE, GST_TYPE_AUTO_CONVERT);
-
-  ret &= gst_element_register (plugin, "autovideoconvert",
-      GST_RANK_NONE, GST_TYPE_AUTO_VIDEO_CONVERT);
+  ret |= GST_ELEMENT_REGISTER (autoconvert, plugin);
+  ret |= GST_ELEMENT_REGISTER (autovideoconvert, plugin);
+  ret |= GST_ELEMENT_REGISTER (autodeinterlace, plugin);
+  ret |= GST_ELEMENT_REGISTER (autovideoflip, plugin);
+  gst_type_mark_as_plugin_api (GST_TYPE_BASE_AUTO_CONVERT, 0);
 
   return ret;
 }
@@ -42,5 +44,5 @@ plugin_init (GstPlugin * plugin)
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
     GST_VERSION_MINOR,
     autoconvert,
-    "Selects convertor element based on caps",
+    "Selects converter element based on caps",
     plugin_init, VERSION, GST_LICENSE, GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN)
