@@ -27,12 +27,10 @@
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  gboolean ret;
+  gboolean ret = FALSE;
 
-  ret = gst_element_register (plugin, "pcapparse",
-      GST_RANK_NONE, GST_TYPE_PCAP_PARSE);
-  ret &= gst_element_register (plugin, "irtspparse",
-      GST_RANK_NONE, GST_TYPE_IRTSP_PARSE);
+  ret |= GST_ELEMENT_REGISTER (pcapparse, plugin);
+  ret |= GST_ELEMENT_REGISTER (irtspparse, plugin);
 
   return ret;
 }
@@ -41,4 +39,4 @@ GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
     GST_VERSION_MINOR,
     pcapparse,
     "Element parsing raw pcap streams",
-    plugin_init, VERSION, "LGPL", "GStreamer", "http://gstreamer.net/")
+    plugin_init, VERSION, "LGPL", GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN)
