@@ -123,7 +123,6 @@ struct _GstV4l2CodecVp9Dec
   GstV4l2CodecAllocator *sink_allocator;
   GstV4l2CodecAllocator *src_allocator;
   GstV4l2CodecPool *src_pool;
-  gboolean has_videometa;
   gboolean streaming;
   gboolean copy_frames;
   gboolean need_negotiation;
@@ -610,11 +609,13 @@ gst_v4l2_codec_vp9_dec_decide_allocation (GstVideoDecoder * decoder,
   GstCaps *caps = NULL;
   guint min = 0;
   guint num_bitstream;
+  gboolean has_videometa;
 
   g_clear_object (&self->src_pool);
   g_clear_object (&self->src_allocator);
+  g_clear_object (&self->sink_allocator);
 
-  self->has_videometa = gst_query_find_allocation_meta (query,
+  has_videometa = gst_query_find_allocation_meta (query,
       GST_VIDEO_META_API_TYPE, NULL);
 
   gst_query_parse_allocation (query, &caps, NULL);
@@ -623,12 +624,34 @@ gst_v4l2_codec_vp9_dec_decide_allocation (GstVideoDecoder * decoder,
     return FALSE;
   }
 
-  if (gst_video_is_dma_drm_caps (caps) && !self->has_videometa) {
+  if (gst_video_is_dma_drm_caps (caps) && !has_videometa) {
     GST_ERROR_OBJECT (self,
         "DMABuf caps negotiated without the mandatory support of VideoMeta");
     return FALSE;
   }
 
+  /* Check if we can zero-copy buffers */
+  if (!has_videometa) {
+    GstVideoInfo ref_vinfo;
+    gint i;
+
+    gst_video_info_set_format (&ref_vinfo,
+        GST_VIDEO_INFO_FORMAT (&self->vinfo_drm.vinfo), self->width,
+        self->height);
+
+    for (i = 0; i < GST_VIDEO_INFO_N_PLANES (&self->vinfo_drm.vinfo); i++) {
+      if (self->vinfo_drm.vinfo.stride[i] != ref_vinfo.stride[i] ||
+          self->vinfo_drm.vinfo.offset[i] != ref_vinfo.offset[i]) {
+        GST_WARNING_OBJECT (self,
+            "GstVideoMeta support required, copying frames.");
+        self->copy_frames = TRUE;
+        break;
+      }
+    }
+  } else {
+    self->copy_frames = FALSE;
+  }
+
   if (gst_query_get_n_allocation_pools (query) > 0)
     gst_query_parse_nth_allocation_pool (query, 0, NULL, NULL, &min, NULL);
 
@@ -774,28 +797,6 @@ gst_v4l2_codec_vp9_dec_new_sequence (GstVp9Decoder * decoder,
     }
   }
 
-  /* Check if we can zero-copy buffers */
-  if (!self->has_videometa) {
-    GstVideoInfo ref_vinfo;
-    gint i;
-
-    gst_video_info_set_format (&ref_vinfo,
-        GST_VIDEO_INFO_FORMAT (&self->vinfo_drm.vinfo), self->width,
-        self->height);
-
-    for (i = 0; i < GST_VIDEO_INFO_N_PLANES (&self->vinfo_drm.vinfo); i++) {
-      if (self->vinfo_drm.vinfo.stride[i] != ref_vinfo.stride[i] ||
-          self->vinfo_drm.vinfo.offset[i] != ref_vinfo.offset[i]) {
-        GST_WARNING_OBJECT (self,
-            "GstVideoMeta support required, copying frames.");
-        self->copy_frames = TRUE;
-        break;
-      }
-    }
-  } else {
-    self->copy_frames = FALSE;
-  }
-
   return GST_FLOW_OK;
 }
 
@@ -876,6 +877,7 @@ gst_v4l2_codec_vp9_dec_end_picture (GstVp9Decoder * decoder,
   GstV4l2CodecVp9Dec *self = GST_V4L2_CODEC_VP9_DEC (decoder);
   GstVideoCodecFrame *frame;
   GstV4l2Request *request = NULL;
+  GstBuffer *buffer;
   GstFlowReturn flow_ret;
   gsize bytesused;
   guint num_controls = 1;
@@ -906,12 +908,8 @@ gst_v4l2_codec_vp9_dec_end_picture (GstVp9Decoder * decoder,
   self->bitstream_map = (GstMapInfo) GST_MAP_INFO_INIT;
   gst_memory_resize (self->bitstream, 0, bytesused);
 
-  frame = gst_video_decoder_get_frame (GST_VIDEO_DECODER (self),
-      GST_CODEC_PICTURE_FRAME_NUMBER (picture));
-  g_return_val_if_fail (frame, FALSE);
-
   flow_ret = gst_buffer_pool_acquire_buffer (GST_BUFFER_POOL (self->src_pool),
-      &frame->output_buffer, NULL);
+      &buffer, NULL);
   if (flow_ret != GST_FLOW_OK) {
     if (flow_ret == GST_FLOW_FLUSHING)
       GST_DEBUG_OBJECT (self, "Frame decoding aborted, we are flushing.");
@@ -921,12 +919,16 @@ gst_v4l2_codec_vp9_dec_end_picture (GstVp9Decoder * decoder,
     goto fail;
   }
 
-  request = gst_v4l2_decoder_alloc_request (self->decoder,
-      GST_CODEC_PICTURE_FRAME_NUMBER (picture), self->bitstream,
-      frame->output_buffer);
-
+  frame = gst_video_decoder_get_frame (GST_VIDEO_DECODER (self),
+      GST_CODEC_PICTURE_FRAME_NUMBER (picture));
+  g_return_val_if_fail (frame, FALSE);
+  g_warn_if_fail (frame->output_buffer == NULL);
+  frame->output_buffer = buffer;
   gst_video_codec_frame_unref (frame);
 
+  request = gst_v4l2_decoder_alloc_request (self->decoder,
+      GST_CODEC_PICTURE_FRAME_NUMBER (picture), self->bitstream, buffer);
+
   if (!request) {
     GST_ELEMENT_ERROR (decoder, RESOURCE, NO_SPACE_LEFT,
         ("Failed to allocate a media request object."), (NULL));
@@ -956,6 +958,10 @@ fail:
     gst_v4l2_request_unref (request);
 
   gst_v4l2_codec_vp9_dec_reset_picture (self);
+
+  if (flow_ret != GST_FLOW_OK)
+    return flow_ret;
+
   return GST_FLOW_ERROR;
 }
 
